import os, ConfigParser

@plugin
class Auth(object):
    def __init__(self, server):
        self.server = server
        self.commands = [ "addadmin", "addmod", "deladmin", "delmod", "admins", "mods", "owners" ]
        self.owners = []
        self.admins = []
        self.mods = []
        self.server.handle("command", self.handle_command, self.commands)
        self.authfile = self.server.config["confdir"] + "auth.conf"
        self._loadusers()
        
    def handle_command(self, channel, user, cmd, args):
        if cmd == "owners":
            self.server.doMessage(channel, user+": My owners are "+" ".join(self.owners))
        elif cmd == "admins":
            self.server.doMessage(channel, user+": My administrators are: "+" ".join(self.admins))
        elif cmd == "mods":
            self.server.doMessage(channel, user+": My moderators are: "+" ".join(self.mods))
            
        elif self.isOwner(user):
            if len(args) < 1:
                self.server.doMessage(channel, user+": Not enough arguments.")
                return
            
            if cmd == "addadmin":
                if args[0] in self.admins: return
                self.admins.append(args[0])
            elif cmd == "addmod":
                if args[0] in self.mods: return
                self.mods.append(args[0])
            elif cmd == "deladmin":
                if args[0] in self.admins:
                    self.admins.remove(args[0])
            elif cmd == "delmod":
                if args[0] in self.mods:
                    self.mods.remove(args[0])
    
    def _loadusers(self):
        if not os.path.isfile(self.authfile):
            return
        
        self.configParser = ConfigParser.RawConfigParser()
        self.configParser.read(self.authfile)
        for section in self.configParser.sections():
            if section == self.server.config["host"]:
                for key,values in self.configParser.items(section):
                    if key == "owners":
                        self.owners += values.split(",")
                    elif key == "admins":
                        self.admins += values.split(",")
                    elif key == "mods":
                        self.mods += values.split(",")
    
    def isOwner(self, user):
        return user in self.owners
    
    def isAdmin(self, user):
        if user in self.admins: 
            return True
        else:
            return user in self.owners
    
    def isMod(self, user):
        if user in self.mods: 
            return True
        elif user in self.admins: 
            return True
        else:
            return user in self.owners
            
